integration

package
v0.0.0-...-8065d48 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const ModuleName = "integration"

ModuleName is the identifier used in assembled migration filenames.

Variables

This section is empty.

Functions

func MigrationSource

func MigrationSource() db.MigrationSource

MigrationSource returns the integration module's migration source for registration in the boot sequence.

Types

This section is empty.

Jump to