Documentation
¶
Index ¶
Constants ¶
const ModuleName = "integration"
ModuleName is the identifier used in assembled migration filenames.
Variables ¶
This section is empty.
Functions ¶
func MigrationSource ¶
func MigrationSource() db.MigrationSource
MigrationSource returns the integration module's migration source for registration in the boot sequence.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.